@@ -7,21 +7,21 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 // Used to set Application in caseinline=APP
-function setApplSpan(SpanID) {
+function setApplSpan(spanZ) {
     var module = getParameterByName("DbPAR");
     if (module === null) {
         module = "WRITER";
     }
-    var y = document.getElementById(SpanID).getElementsByTagName("SPAN");
+    var y = spanZ.getElementsByTagName("SPAN");
     var n = y.length;
-    var foundSystem = false;
+    var foundAppl = false;
     for (i = 0; i < n; i++) {
         if (y[i].getAttribute("id") === null){
             continue;
         }
         else if( y[i].getAttribute("id").startsWith(module)){
             y[i].removeAttribute("hidden");
-            foundSystem=true;
+            foundAppl=true;
         }
     }
     for (i = 0; i < n; i++) {
@@ -29,20 +29,20 @@ function setApplSpan(SpanID) {
             continue;
         }
         else if( y[i].getAttribute("id").startsWith("default")){
-            if(!foundSystem){
+            if(!foundAppl){
                 y[i].removeAttribute("hidden");
             }
         }
     }
 }
 // Used to set system in case, caseinline=SYSTEM
-function setSystemSpan(spanID) {
-    var system = getParameterByName("System");
+function setSystemSpan(spanZ) {
     // if no System in URL, get browser system
+    var system = getParameterByName("System");
     if (system === null) {
         system = getSystem();
     }
-    var y = document.getElementById(spanID).getElementsByTagName("SPAN");
+    var y = spanZ.getElementsByTagName("SPAN");
     var n = y.length;
     var foundSystem = false;
     for (i = 0; i < n; i++) {
@@ -65,6 +65,36 @@ function setSystemSpan(spanID) {
         }
     }
 }
+
+// paint headers and headings with appl color
+
+function moduleColor (module) {
+    switch (module){
+        case "WRITER" : {color="#0369A3"; break;}
+        case "CALC"   : {color="#43C330"; break;}
+        case "CHART"  : {color="darkcyan"; break;}
+        case "IMPRESS": {color="#A33E03"; break;}
+        case "DRAW"   : {color="#C99C00"; break;}
+        case "BASE"   : {color="#8E03A3"; break;}
+        case "BASIC"  : {color="black"; break;}
+        case "MATH"   : {color="darkslategray"; break;}
+        case "SHARED" : {color="gray"; break;}
+        default : {color="#18A303"; break;}
+    }
+    document.getElementById("TopLeftHeader").style.background = color;
+    document.getElementById("SearchFrame").style.background = color;
+    document.getElementById("DonationFrame").style.background = color;
+    var cols = document.getElementsByClassName('tableheadcell');
+    for(i = 0; i < cols.length; i++) {cols[i].style.backgroundColor = color;};
+    for (j of [1,2,3,4,5,6]) {
+        var hh = document.getElementsByTagName("H" + j);
+        for(i = 0; i < hh.length; i++) {
+            hh[i].style.color = color;
+            hh[i].style.borderBottomColor = color;
+        }
+    }
+}
+
 // Find spans that need the switch treatment and give it to them
 var spans = document.querySelectorAll("[class^=switch]");
 var n = spans.length;
@@ -74,9 +104,9 @@ for (z = 0; z < n; z++) {
         continue;
     }
     else if (id.startsWith("swlnsys")) {
-        setSystemSpan(id);
+        setSystemSpan(spans[z]);
     } else {
-        setApplSpan(id);
+        setApplSpan(spans[z]);
     }
 }
 /* add &DbPAR= and &System= to the links in DisplayArea div */
@@ -153,29 +183,29 @@ function existingLang(lang) {
     return 'en-US';
 }
 
-function setupModules(target, lang) {
+function setupModules(lang) {
     var modulesNav = document.getElementById('modules-nav');
     if (!modulesNav.classList.contains('loaded')) {
         var html =
-            '<a href="' + target + lang + '/text/swriter/main0000.html?DbPAR=WRITER"><div class="writer-icon"></div>Writer</a>' +
-            '<a href="' + target + lang + '/text/scalc/main0000.html?DbPAR=CALC"><div class="calc-icon"></div>Calc</a>' +
-            '<a href="' + target + lang + '/text/simpress/main0000.html?DbPAR=IMPRESS"><div class="impress-icon"></div>Impress</a>' +
-            '<a href="' + target + lang + '/text/sdraw/main0000.html?DbPAR=DRAW"><div class="draw-icon"></div>Draw</a>' +
-            '<a href="' + target + lang + '/text/shared/explorer/database/main.html?DbPAR=BASE"><div class="base-icon"></div>Base</a>' +
-            '<a href="' + target + lang + '/text/smath/main0000.html?DbPAR=MATH"><div class="math-icon"></div>Math</a>' +
-            '<a href="' + target + lang + '/text/schart/main0000.html?DbPAR=CHART"><div class="chart-icon"></div>Chart</a>' +
-            '<a href="' + target + lang + '/text/sbasic/shared/main0601.html?DbPAR=BASIC"><div class="basic-icon"></div>Basic</a>';
+            '<a href="' + lang + '/text/swriter/main0000.html?DbPAR=WRITER"><div class="writer-icon"></div>Writer</a>' +
+            '<a href="' + lang + '/text/scalc/main0000.html?DbPAR=CALC"><div class="calc-icon"></div>Calc</a>' +
+            '<a href="' + lang + '/text/simpress/main0000.html?DbPAR=IMPRESS"><div class="impress-icon"></div>Impress</a>' +
+            '<a href="' + lang + '/text/sdraw/main0000.html?DbPAR=DRAW"><div class="draw-icon"></div>Draw</a>' +
+            '<a href="' + lang + '/text/sdatabase/main.html?DbPAR=BASE"><div class="base-icon"></div>Base</a>' +
+            '<a href="' + lang + '/text/smath/main0000.html?DbPAR=MATH"><div class="math-icon"></div>Math</a>' +
+            '<a href="' + lang + '/text/schart/main0000.html?DbPAR=CHART"><div class="chart-icon"></div>Chart</a>' +
+            '<a href="' + lang + '/text/sbasic/shared/main0601.html?DbPAR=BASIC"><div class="basic-icon"></div>Basic</a>';
         modulesNav.innerHTML = html;
         modulesNav.classList.add('loaded');
     }
 }
 
-function setupLanguages(target, page) {
+function setupLanguages(page) {
     var langNav = document.getElementById('langs-nav');
     if (!langNav.classList.contains('loaded')) {
         var html = '';
         languagesSet.forEach(function(lang) {
-            html += '<a href="' + target + lang + page + '">' + ((lang in languageNames)? languageNames[lang]: lang) + '</a>';
+            html += '<a href="' + lang + page + '">' + ((lang in languageNames)? languageNames[lang]: lang) + '</a>';
         });
         langNav.innerHTML = html;
         langNav.classList.add('loaded');
@@ -202,8 +232,12 @@ if (document.body.getElementsByTagName('meta')) {
 }
 
 var module = getParameterByName("DbPAR");
-var helpID = getParameterByName("HID");
 fixURL(module,system);
+moduleColor(module);
+var helpID = getParameterByName("HID");
+// only used in xhp pages with <help-id-missing/> tags
+var missingElement = document.getElementById("bm_HID2");
+if(missingElement != null){missingElement.innerHTML = helpID;}
 
 function debugInfo(dbg) {
     if (dbg == null) return;
